# Nowcasting Forecast
Making live forecasts for the nowcasting project

In development!!!!

Rough idea of this project
1. load data
2. create GSP level data ready for ML
3. Run thorugh ML model
4. Save model to database

![Models](diagram.png)
